#!/bin/bash

function ccommand() {
    echo $1
    podman exec -it 20240510-x509-indempotency /bin/bash -c "${1}"
}

function testblock() {
    ccommand "ansible -m community.crypto.openssl_privatekey -u root -a "path=/root/private.key" localhost"
    ccommand "ansible -m community.crypto.openssl_csr -u root -a \"privatekey_path=/root/private.key common_name=CATest use_common_name_for_san=False basic_constraints=CA:TRUE basic_constraints_critical=True key_usage=keyCertSign key_usage_critical=True path=/root/CAcert.csr\" localhost"
    ccommand "ansible -m community.crypto.x509_certificate -u root -a 'path=/root/CACert.pem csr_path=/root/CAcert.csr ignore_timestamps=False selfsigned_not_before=20230101000000Z selfsigned_not_after=20260101000000Z privatekey_path=/root/private.key provider=selfsigned' localhost"
    ccommand "cp /root/CACert.pem /root/CACert1.pem"
    ccommand "ansible -m community.crypto.x509_certificate -u root -a 'path=/root/CACert.pem csr_path=/root/CAcert.csr ignore_timestamps=False selfsigned_not_before=20230101000000Z selfsigned_not_after=20260101000000Z privatekey_path=/root/private.key provider=selfsigned' localhost"
    ccommand "cp /root/CACert.pem /root/CACert2.pem"
    ccommand "md5sum /root/CACert1.pem /root/CACert2.pem"
}

# preparation
podman run -d --name 20240510-x509-indempotency --replace -t=0 fedora:40 /bin/bash -c "sleep infinity"
ccommand "dnf upgrade --refresh"
ccommand "dnf install -y pip less"
ccommand "pip install ansible"
ccommand "ansible --version"
ccommand "ansible-config dump --only-changed"

# run test with 2.17.1
ccommand "ansible-galaxy collection install community.crypto==2.17.1"
ccommand "ansible-galaxy collection list community.crypto"
testblock

# run test with 2.19.0
ccommand "ansible-galaxy collection install community.crypto==2.19.0"
ccommand "ansible-galaxy collection list community.crypto"
testblock

# To manually inspect the situation in the container:
# podman exec -it 20240510-x509-indempotency /bin/bash

# ---

# To clean up container after test
podman container stop -t=0 20240510-x509-indempotency
podman container rm 20240510-x509-indempotency
